==> ejc-settle-api-3.0.0-20250111.084612-130-sources.jar: com/ejianc/business/settle/hystrix/SettlementCenterDcDrwgrpInfoHystrix.java <==
package com.ejianc.business.settle.hystrix;

import com.ejianc.business.settle.api.ISettlementCenterDcDrwgrpInfoApi;
import com.ejianc.business.settle.bean.*;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
public class SettlementCenterDcDrwgrpInfoHystrix implements ISettlementCenterDcDrwgrpInfoApi {
    @Override
    public CommonResponse<SettlementCenterDcDrwgrpInfoVO> saveOrUpdateSettlementCenterDcDrwgrpInfo(SettlementCenterDcDrwgrpInfoVO saveOrUpdateVO) {
        return CommonResponse.error("保存结算中心卷册信息失败");
    }

    @Override
    public CommonResponse<SettlementCenterBudgetFeeVO> saveOrUpdateSettlementCenterBudgetFee(SettlementCenterBudgetFeeVO saveOrUpdateVO) {
        return CommonResponse.error("保存其他费用失败");
    }

    @Override
    public CommonResponse<SettlementCenterBudgetMeasureVO> saveOrUpdateSettlementCenterBudgetMeasure(SettlementCenterBudgetMeasureVO saveOrUpdateVO) {
        return CommonResponse.error("保存设备及安装工程失败");
    }

    @Override
    public CommonResponse<SettlementCenterBudgetOtherVO> saveOrUpdateSettlementCenterBudgetOther(SettlementCenterBudgetOtherVO saveOrUpdateVO) {
        return CommonResponse.error("保存建筑工程失败");
    }

    @Override
    public CommonResponse<SettlementCenterBudgetSubVO> saveOrUpdateSettlementCenterBudgetSub(SettlementCenterBudgetSubVO saveOrUpdateVO) {
        return CommonResponse.error("保存施工辅助工程失败");
    }

    @Override
    public CommonResponse<String> deleteForDrwgrp(List<Long> dcDrwgrpId) {
        return CommonResponse.error("保存施工辅助工程失败");
    }

    @Override
    public CommonResponse<List<SettlementCenterDrawPlanDetailVO>> queryListByProjectId(Long projectId) {
        return CommonResponse.error("获取到图计划失败");
    }
}

==> ejc-settle-api-3.0.0-20250121.072225-147-sources.jar: com/ejianc/business/settle/hystrix/SettlementCenterDcDrwgrpInfoHystrix.java <==
package com.ejianc.business.settle.hystrix;

import com.ejianc.business.settle.api.ISettlementCenterDcDrwgrpInfoApi;
import com.ejianc.business.settle.bean.*;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
public class SettlementCenterDcDrwgrpInfoHystrix implements ISettlementCenterDcDrwgrpInfoApi {
    @Override
    public CommonResponse<SettlementCenterDcDrwgrpInfoVO> saveOrUpdateSettlementCenterDcDrwgrpInfo(SettlementCenterDcDrwgrpInfoVO saveOrUpdateVO) {
        return CommonResponse.error("保存结算中心卷册信息失败");
    }

    @Override
    public CommonResponse<SettlementCenterBudgetFeeVO> saveOrUpdateSettlementCenterBudgetFee(SettlementCenterBudgetFeeVO saveOrUpdateVO) {
        return CommonResponse.error("保存其他费用失败");
    }

    @Override
    public CommonResponse<SettlementCenterBudgetMeasureVO> saveOrUpdateSettlementCenterBudgetMeasure(SettlementCenterBudgetMeasureVO saveOrUpdateVO) {
        return CommonResponse.error("保存设备及安装工程失败");
    }

    @Override
    public CommonResponse<SettlementCenterBudgetOtherVO> saveOrUpdateSettlementCenterBudgetOther(SettlementCenterBudgetOtherVO saveOrUpdateVO) {
        return CommonResponse.error("保存建筑工程失败");
    }

    @Override
    public CommonResponse<SettlementCenterBudgetSubVO> saveOrUpdateSettlementCenterBudgetSub(SettlementCenterBudgetSubVO saveOrUpdateVO) {
        return CommonResponse.error("保存施工辅助工程失败");
    }

    @Override
    public CommonResponse<String> deleteForDrwgrp(List<Long> dcDrwgrpId) {
        return CommonResponse.error("保存施工辅助工程失败");
    }

    @Override
    public CommonResponse<List<SettlementCenterDrawPlanDetailVO>> queryListByProjectId(Long projectId) {
        return CommonResponse.error("获取到图计划明细失败");
    }

    @Override
    public CommonResponse<SettlementCenterDrawPlanVO> queryDetailForDrwgrp(Long id) {
        return CommonResponse.error("获取到图计划失败");
    }
}
